@@ -117,6 +117,14 @@ class TrackMeTrackerExecutor(GeneratingCommand):
         default=None,
     )
 
+    force_savedsearch_execmode = Option(
+        doc="""
+        **Syntax:** **force_savedsearch_execmode=****
+        **Description:** force execution mode to be savedsearch.""",
+        require=False,
+        default=False,
+    )    
+
     earliest = Option(
         doc="""
         **Syntax:** **earliest=****
@@ -305,9 +313,12 @@ class TrackMeTrackerExecutor(GeneratingCommand):
                 raise Exception(f'tenant_id="{self.tenant_id}", component="{self.component}", report="{self.report}", savedsearch definition not found, this means that this tracker is corrupted and the wrapper was deleted, execution cannot be completed.')
 
             # if we have args, we will execute the report through the savedsearch command
-            # otherwise execute the search directly
+            # otherwise execute the search directly unless force_savedsearch_execmode is True
             if self.args:
                 search = f'| savedsearch "{self.report}" {self.args}'
+            elif self.force_savedsearch_execmode:
+                logging.info(f'tenant_id="{self.tenant_id}", component="{self.component}", report="{self.report}", force_savedsearch_execmode is True, executing the search directly through the savedsearch command')
+                search = f'| savedsearch "{self.report}"'
             else:
                 search = savedsearch_definition
                 # if the search does not start with a generating command, which means with a |, add "search" before the search definition
